/*
 * Standard C99 implementation (partial) of stdio for Casio 9860g(SD)
 * 
 */

#ifndef _STDIO_H
#define _STDIO_H

#include <stdarg.h>
#include <stddef.h>

//If the C compiler isn't C99, the 'restrict' keyword don't exist
#ifndef restrict
#define restrict
#endif

//Constants externals definition
#ifndef NULL
#define NULL ((void*)0)
#endif

#define _IOFBF 1
#define _IOLBF 2
#define _IONBF 3

#define BUFSIZ 256
#define EOF (-1)
#define FOPEN_MAX 8
#define FILENAME_MAX 13

#define SEEK_CUR 0
#define SEEK_END 1
#define SEEK_SET 2

#define TMP_MAX 0
//#define L_tmpnam

typedef unsigned int fpos_t;

struct _FILE;
typedef struct _FILE FILE;

extern FILE *__files[];

#define stderr (__files[2])
#define stdin (__files[0])
#define stdout (__files[1])


//Functions
int remove(const char *filename);
int rename(const char *old, const char *new);
int fclose(FILE *stream);
int fflush(FILE *stream);
FILE *fopen(const char * filename, const char * mode);
FILE *freopen(const char * filename, const char * mode, FILE * stream);
void setbuf(FILE * stream, char * buf);
int setvbuf(FILE * restrict stream, char * buf, int mode, size_t size);
int fprintf(FILE * restrict stream, const char * restrict format, ...);
int fscanf(FILE * restrict stream, const char * restrict format, ...);
//int printf(const char * restrict format, ...);
//int scanf(const char * restrict format, ...);
int snprintf(char * restrict s, size_t n, const char * restrict format, ...);
int sprintf(char * restrict s, const char * restrict format, ...);
int sscanf(const char * restrict s, const char * restrict format, ...);
int vfprintf(FILE * restrict stream, const char * restrict format, va_list arg);
int vfscanf(FILE * restrict stream, const char * restrict format, va_list arg);
int vprintf(const char * restrict format, va_list arg);
int vscanf(const char * restrict format, va_list arg);
int vsnprintf(char * restrict s, size_t n, const char * restrict format, va_list arg);
int vsprintf(char * restrict s, const char * restrict format, va_list arg);
int vsscanf(const char * restrict s, const char * restrict format, va_list arg);
int fgetc(FILE *stream);
char *fgets(char * restrict s, int n, FILE * restrict stream);
int fputc(int c, FILE *stream);
int fputs(const char * restrict s, FILE * restrict stream);
int getc(FILE *stream);
int getchar(void);
char *gets(char *s);
int putc(int c, FILE *stream);
int putchar(int c);
int puts(const char *s);
int ungetc(int c, FILE *stream);
size_t fread(void * restrict ptr, size_t size, size_t nmemb, FILE * restrict stream);
size_t fwrite(const void * restrict ptr, size_t size, size_t nmemb, FILE * restrict stream);
int fgetpos(FILE * restrict stream, fpos_t * restrict pos);
int fseek(FILE *stream, long int offset, int whence);
int fsetpos(FILE *stream, const fpos_t *pos);
long int ftell(FILE *stream);
void rewind(FILE *stream);
void clearerr(FILE *stream);
int feof(FILE *stream);
int ferror(FILE *stream);
void perror(const char *s);


/*
FILE *tmpfile(void);
char *tmpnam(char *s);

*/

#endif // _STDIO_H
